#!/bin/sh

# detect OCPP master/slave setup
function_is_ocpp_master_slave()
{
	if [[ -e /home/charge/persistency/MasterMode_ms ]]; then
		grep -q 'On' /home/charge/persistency/MasterMode_ms > /dev/null 2>&1
 		if [ $? -eq 0 ]; then
         	# On found, must be OCPP master
 			return 1
 		fi
 	fi
 	if [[ -e /home/charge/persistency/SlaveMode_ms ]]; then
		grep -q 'On' /home/charge/persistency/SlaveMode_ms > /dev/null 2>&1
 		if [ $? -eq 0 ]; then
         	# On found, must be OCPP slave
 			return 2
 		fi
 	fi
 	
 	# standalone case
 	return 0
}

function_is_ocpp_master_slave
ret_val=$?

if [ $ret_val -eq 0 ]; then
	return
fi

logger "Starting port forwarding between OCPP Master and Slave"

socat -ly tcp4-listen:81,fork,reuseaddr tcp4-connect:192.168.125.124:80 &
socat -ly tcp4-listen:23,fork,reuseaddr tcp4-connect:192.168.125.124:22 &
socat -ly tcp4-listen:82,fork,reuseaddr tcp4-connect:192.168.125.125:80 &
socat -ly tcp4-listen:24,fork,reuseaddr tcp4-connect:192.168.125.125:22 &

# firmware upload and log download
socat -ly tcp4-listen:8021,fork,reuseaddr tcp4-connect:192.168.125.124:8020 &
socat -ly tcp4-listen:8022,fork,reuseaddr tcp4-connect:192.168.125.125:8020 &

# Modbus TCP Slave: Only forward anything if it's the OCPP master
if [ $ret_val -eq 1 ]; then
  logger "Starting port forwarding for Modbus TCP Slave"
  modbus_base_port=502 # set the default
  if [ -e /home/charge/persistency/TCPPortNumber_modbus_slave ]; then
      modbus_base_port=$(head -n 1 /home/charge/persistency/TCPPortNumber_modbus_slave)
  fi;
  socat -ly tcp4-listen:$((modbus_base_port+1)),fork,reuseaddr tcp4-connect:192.168.125.125:$modbus_base_port &
    
  logger "Starting port forwarding for ASKI over OCPP-S"
  socat -ly tcp4-listen:13001,fork,reuseaddr tcp4-connect:192.168.125.125:13000 &    
fi
